@@ -1,6 +1,8 @@
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
+from typing import Optional
+
 import attr
 
 
@@ -39,7 +41,7 @@ class DataSource:
     client_id_column = attr.ib(default='client_id', type=str)
     submission_date_column = attr.ib(default='submission_date', type=str)
 
-    EXPERIMENT_COLUMN_TYPES = (None, "simple", "native")
+    EXPERIMENT_COLUMN_TYPES = (None, "simple", "native", "glean")
 
     @experiments_column_type.validator
     def _check_experiments_column_type(self, attribute, value):
@@ -71,7 +73,12 @@ class DataSource:
             )"""
 
         elif self.experiments_column_type == 'glean':
-            raise NotImplementedError
+            return """AND (
+                    ds.{submission_date} != e.enrollment_date
+                    OR `mozfun.map.get_key`(
+                        ds.ping_info.experiments, '{experiment_slug}'
+                    ).branch IS NOT NULL
+                )"""
 
         else:
             raise ValueError
@@ -154,7 +161,22 @@ class DataSource:
             ]
 
         elif self.experiments_column_type == 'glean':
-            raise NotImplementedError
+            return [
+                Metric(
+                    name=self.name + '_has_contradictory_branch',
+                    data_source=self,
+                    select_expr=agg_any("""`mozfun.map.get_key`(
+                ds.ping_info.experiments, '{experiment_slug}'
+            ).branch != e.branch"""),
+                ),
+                Metric(
+                    name=self.name + '_has_non_enrolled_data',
+                    data_source=self,
+                    select_expr=agg_any("""`mozfun.map.get_key`(
+                ds.ping_info.experiments, '{experiment_slug}'
+            ).branch IS NULL""".format(experiment_slug=experiment_slug))
+                ),
+            ]
 
         else:
             raise ValueError
@@ -165,10 +187,23 @@ class Metric:
     """Represents an experiment metric.
 
     Needs to be combined with an analysis window to be measurable!
+
+    Args:
+        name (str): A slug; uniquely identifies this metric in tables
+        data_source (DataSource): where to find the metric
+        select_expr (str): a SQL snippet representing a clause of a SELECT
+            expression describing how to compute the metric; must include an
+            aggregation function since it will be GROUPed BY client_id
+            and branch
+        friendly_name (str): A human-readable dashboard title for this metric
+        description (str): A paragraph of Markdown-formatted text describing
+            what the metric measures, to be shown on dashboards
     """
     name = attr.ib(type=str)
     data_source = attr.ib(type=DataSource)
     select_expr = attr.ib(type=str)
+    friendly_name = attr.ib(type=Optional[str], default=None)
+    description = attr.ib(type=Optional[str], default=None)
 
     def from_data_source(self, data_source: DataSource) -> "Metric":
         """Returns an instance of the Metric drawing from a different DataSource.
